/**
 * wrapper for banners
 * @moduleName BannerAd
 */
bento.define('modules/banner', [
    'bento',
    'bento/eventsystem',
    'modules/ironsource',
    'globals',
    'bento/entity',
    'bento/math/rectangle',
    'bento/components/fill'
], function (
    Bento,
    EventSystem,
    IronSource,
    Globals,
    Entity,
    Rectangle,
    Fill
) {
    'use strict';

    /**
     * Main module
     */
    var isExpected = false;
    var BannerAd = {
        /**
         * @snippet BannerAd.showBanner|snippet
BannerAd.showBanner();
         */
        init: function () {
            var viewport = Bento.getViewport();
            var bannerHeight = 24 + ((viewport.height / viewport.width > 2.1) ? 17 : 0);
            var bannerBack = new Entity({
                z: Globals.layers.banner,
                name: 'bannerBacking',
                alpha: 0,
                global: true,
                float: true,
                components: [
                    new Fill({
                        dimension: new Rectangle(0, viewport.height - bannerHeight, viewport.width, bannerHeight),
                        color: [0, 0, 0, 1]
                    }), {
                        name: 'hiderBehaviour',
                        update: function () {
                            bannerBack.alpha = (BannerAd.getIsExpected()) ? 0.5 : 0;
                        }
                    }
                ]
            });
            Bento.objects.attach(bannerBack);
        },
        showBanner: function (settings) {
            var bannerStatus = IronSource.getBannerStatus();
            if (!settings || settings && !settings.noAds) {
                if (!bannerStatus.visible) {
                    IronSource.showBanner(function () {
                        EventSystem.fire('bannerStatusChanged', {});
                    });
                } else {
                    EventSystem.fire('bannerStatusChanged', {});
                }
                isExpected = true;
            } else {
                if (bannerStatus.prepared) {
                    IronSource.removeBannerView(function () {
                        EventSystem.fire('bannerStatusChanged', {});
                    });
                    isExpected = false;
                }
            }
        },
        /**
         * @snippet BannerAd.isVisible|snippet
BannerAd.isVisible()
         */
        isVisible: function () {
            return IronSource.isBannerVisible();
        },
        getIsExpected: function () {
            return isExpected;
        },
        /**
         * @snippet BannerAd.hideBanner|snippet
BannerAd.hideBanner();
         */
        hideBanner: function (settings) {
            var bannerStatus = IronSource.getBannerStatus();
            if (bannerStatus.visible) {
                IronSource.hideBanner(function () {
                    EventSystem.fire('bannerStatusChanged', {});
                    isExpected = false;
                });
            } else {
                isExpected = false;
            }
        },
        /**
         * @snippet BannerAd.removeBanner|snippet
BannerAd.removeBanner();
         */
        removeBanner: function (settings) {
            var bannerStatus = IronSource.getBannerStatus();
            if (bannerStatus.prepared) {
                IronSource.removeBannerView(function () {
                    EventSystem.fire('bannerStatusChanged', {});
                });
                isExpected = false;
            }
        },
    };
    return BannerAd;
});